@@ -64,7 +64,7 @@ if 'oscar' in settings.INSTALLED_APPS:
     class StaticSitemap(I18nSitemap):
 
         def items(self):
-            return ['promotions:home', ]
+            return ['promotions-home', ]
 
         def get_obj_location(self, obj):
             return reverse(obj)
